@@ -20,6 +20,8 @@ class GbpOptionParser(OptionParser):
     @cvar defaults: defaults value of an option if not in the config file or
     given on the command line
     @type defaults: dict
+    @cvar help: help messages
+    @type help: dict
     @cvar config_files: list of config files we parse
     @type config_files: list
     """
@@ -44,13 +46,39 @@ class GbpOptionParser(OptionParser):
                  'meta-closes'     : 'Closes|LP',
                  'id-length'       : '0',
                  'no-dch'          : 'False',
+                 'git-author'      : 'False',
              }
+    help = {
+             'debian-branch':
+                  "branch the Debian package is being developed on, default is '%(debian-branch)s'",
+             'upstream-branch':
+                  "upstream branch, default is '%(upstream-branch)s'",
+             'debian-tag':
+                  "format string for debian tags, default is '%(debian-tag)s'",
+             'upstream-tag':
+                  "format string for upstream tags, default is '%(upstream-tag)s'",
+             'sign-tags':
+                  "sign tags, default is '%(sign-tags)s'",
+             'no-sign-tags':
+                  "negates sign-tags",
+             'keyid':
+                  "GPG keyid to sign tags with, default is '%(keyid)s'",
+             'pristine-tar':
+                  "use pristine-tar to create .orig.tar.gz, default is '%(pristine-tar)s'",
+             'filter':
+                  "files to filter out during import (can be given multiple times)",
+             'git-author':
+                  "use name and email from git-config for changelog trailer, default is '%(git-author)s'",
+             'no-git-author':
+                  "negates git-author",
+           }
     config_files = [ '/etc/git-buildpackage/gbp.conf',
                      os.path.expanduser('~/.gbp.conf'),
                      '.gbp.conf',
                      'debian/gbp.conf',
                      '.git/gbp.conf' ]
 
+
     def __parse_config_files(self):
         """parse the possible config files and set appropriate values default values"""
         parser = SafeConfigParser(self.defaults)
@@ -73,17 +101,48 @@ class GbpOptionParser(OptionParser):
         self.__parse_config_files()
         OptionParser.__init__(self, usage=usage, version='%s %s' % (self.command, gbp_version))
 
+    def _is_boolean(self, option_name, *args, **kwargs):
+        """is option_name a boolean option"""
+        ret = False
+        try:
+            if kwargs['action'] in [ 'store_true', 'store_false' ]:
+                ret=True
+        except KeyError:
+            ret=False
+        return ret
+
+    def _get_bool_default(self, option_name):
+        """
+        get default for boolean options
+        this way we can handle no-foo=True and foo=False
+        """
+        if option_name.startswith('no-'):
+            pos = option_name[3:]
+            neg = option_name
+        else:
+            pos = option_name
+            neg = "no-%s" % option_name
+
+        try:
+            default = self.config[pos]
+        except KeyError:
+            default = self.config[neg]
+
+        if default in  [ 'True', 'False' ]:
+            ret = eval(default)
+        else:
+            raise ValueError, "Boolean options must be True or False"
+        return ret
+
     def get_default(self, option_name, **kwargs):
-        default = self.config[option_name]
-        if kwargs.has_key('action'):
-            if kwargs['action'] in [ 'store_true', 'store_false' ] and self.config[option_name]:
-                    if self.config[option_name] in  [ 'True', 'False' ]:
-                        default = eval(self.config[option_name])
-                    else:
-                        raise ValueError, "Boolean options must be True or False"
+        """get the default value"""
+        if self._is_boolean(self, option_name, **kwargs):
+            default = self._get_bool_default(option_name)
+        else:
+            default = self.config[option_name]
         return default
 
-    def add_config_file_option(self, option_name, dest, help, **kwargs):
+    def add_config_file_option(self, option_name, dest, help=None, **kwargs):
         """
         set a option for the command line parser, the default is read from the config file
         @var option_name: name of the option
@@ -93,12 +152,14 @@ class GbpOptionParser(OptionParser):
         @var help: help text
         @type help: string
         """
+        if not help:
+            help = self.help[option_name]
         OptionParser.add_option(self, "--%s%s" % (self.prefix, option_name), dest=dest,
                                 default=self.get_default(option_name, **kwargs),
                                 help=help % self.config, **kwargs)
 
 class GbpOptionGroup(OptionGroup):
-    def add_config_file_option(self, option_name, dest, help, **kwargs):
+    def add_config_file_option(self, option_name, dest, help=None, **kwargs):
         """
         set a option for the command line parser, the default is read from the config file
         @var option_name: name of the option
@@ -108,6 +169,8 @@ class GbpOptionGroup(OptionGroup):
         @var help: help text
         @type help: string
         """
+        if not help:
+            help = self.parser.help[option_name]
         OptionGroup.add_option(self, "--%s%s" % (self.parser.prefix, option_name), dest=dest,
                                 default=self.parser.get_default(option_name, **kwargs),
                                 help=help % self.parser.config, **kwargs)
